==> calligra-2.9.8.tar.xz: calligra-2.9.8/plugins/artistictextshape/ArtisticTextShapePlugin.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ArtisticTextShapePlugin.h"
#include "ArtisticTextShapeFactory.h"
#include "ArtisticTextToolFactory.h"

#include <KoShapeRegistry.h>
#include <KoToolRegistry.h>

#include <kpluginfactory.h>

K_PLUGIN_FACTORY(ArtisticTextShapePluginFactory, registerPlugin<ArtisticTextShapePlugin>();)
K_EXPORT_PLUGIN(ArtisticTextShapePluginFactory("calligra_shape_artistictext"))

ArtisticTextShapePlugin::ArtisticTextShapePlugin( QObject * parent, const QVariantList & )
    : QObject(parent)
{
    KoShapeRegistry::instance()->add( new ArtisticTextShapeFactory() );
    KoToolRegistry::instance()->add( new ArtisticTextToolFactory() );
}

ArtisticTextShapePlugin::~ArtisticTextShapePlugin()
{
}

#include <ArtisticTextShapePlugin.moc>

==> calligra_3.1.0.1+rb2.orig.tar.xz: calligra-3.1.0.1+rb2/plugins/artistictextshape/ArtisticTextShapePlugin.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ArtisticTextShapePlugin.h"
#include "ArtisticTextShapeFactory.h"
#include "ArtisticTextToolFactory.h"

#include <KoShapeRegistry.h>
#include <KoToolRegistry.h>

#include <kpluginfactory.h>

K_PLUGIN_FACTORY_WITH_JSON(ArtisticTextShapePluginFactory, "calligra_shape_artistictext.json",
                 registerPlugin<ArtisticTextShapePlugin>();)

ArtisticTextShapePlugin::ArtisticTextShapePlugin( QObject * parent, const QVariantList & )
    : QObject(parent)
{
    KoShapeRegistry::instance()->add( new ArtisticTextShapeFactory() );
    KoToolRegistry::instance()->add( new ArtisticTextToolFactory() );
}

ArtisticTextShapePlugin::~ArtisticTextShapePlugin()
{
}

#include <ArtisticTextShapePlugin.moc>
